@@ -26,7 +26,7 @@ See L<https://github.com/mche/Mojolicious-Plugin-RoutesAuthDBI/blob/master/Diagr
     
     my @path = split(/\//, __FILE__ );
     my $file = join('/', @path[0 .. $#path -1], 'POS/Pg.pm');
-    my $pos = DBIx::POS::Template->new($file, enc => 'utf8');
+    my $pos = DBIx::POS::Template->new($file,);
     my $sth = $dbh->prepare($pos->{'user'});
 
 =head1 SEE ALSO
@@ -45,6 +45,10 @@ L<DBIx::POS::Template>
 
 =desc
 
+=param
+
+  {cached=>1}
+
 =sql
 
   select *
@@ -75,7 +79,7 @@ L<DBIx::POS::Template>
           left join {% $schema %}namespaces n on n.id=r2.id1
       ) c on a.id=c._id
     ) ac on rf.id2=ac.id
-  order by r.order_by, r.ts;
+  order by r.ts - (coalesce(r.interval_ts, 0::int)::varchar || ' second')::interval;
 
 =item * B<user roles> 
 
@@ -83,6 +87,10 @@ L<DBIx::POS::Template>
 
 =desc Роли пользователя
 
+=param
+
+  {cached=>1}
+
 =sql
 
   select g.*
@@ -98,6 +106,10 @@ L<DBIx::POS::Template>
 
 =desc check if ref between [IDs1] and [IDs2] exists
 
+=param
+
+  {cached=>1}
+
 =sql
 
   select count(*)
@@ -110,6 +122,10 @@ L<DBIx::POS::Template>
 
 =desc доступ к действию в контроллере (действие-каллбак - доступ проверяется по его ID)
 
+=param
+
+  {cached=>1}
+
 =sql
 
   select count(r.*)
@@ -132,6 +148,10 @@ L<DBIx::POS::Template>
 
 =desc доступ ко всем действиям по имени пути
 
+=param
+
+  {cached=>1}
+
 =sql
 
   select count(n.*)
@@ -151,6 +171,10 @@ L<DBIx::POS::Template>
 
 =desc Доступ по роли
 
+=param
+
+  {cached=>1}
+
 =sql
 
   select count(*)
@@ -253,6 +277,10 @@ L<DBIx::POS::Template>
 
 =desc Не пустой namespace - четко привязанный контроллер, пустой - обязательно не привязанный контроллер
 
+=param
+
+  {cached=>1}
+
 =sql
 
   select * from (
@@ -305,7 +333,7 @@ L<DBIx::POS::Template>
 
 =sql
 
-  insert into {% $schema %}routes (request, name, descr, auth, disable, order_by)
+  insert into {% $schema %}routes (request, name, descr, auth, disable, interval_ts)
   values (?,?,?,?,?,?)
   returning *;
 
@@ -356,12 +384,14 @@ L<DBIx::POS::Template>
 
 =name namespaces
 
-=desc
+=desc Используется в плугине
 
 =sql
 
   select *
-  from {% $schema %}namespaces;
+  from {% $schema %}namespaces
+  {% $where %}
+  {% $order %};
 
 =item * B<namespace>
 
@@ -383,7 +413,7 @@ L<DBIx::POS::Template>
 
 =sql
 
-  insert into {% $schema %}namespaces (namespace, descr) values (?,?)
+  insert into {% $schema %}namespaces (namespace, descr, app_ns, interval_ts) values (?,?,?,?)
   returning *;
 
 
